@@ -8,6 +8,7 @@ from PIL import Image
 class Record:
     def __init__(self):
         self.id = None
+        self.pki = None
         self.enum_mode = None
         self.uint32_t_created = None
         self.uint32_t_modified = None
@@ -22,6 +23,8 @@ class Record:
     def from_json(self, data):
         if 'id' in data:
             self.id = data['id']
+        if 'pki' in data:
+            self.pki = data['pki']
         if 'enum_mode' in data:
             self.enum_mode = data['enum_mode']
         if 'uint32_t_created' in data:
@@ -47,6 +50,7 @@ class Record:
 class Position:
     def __init__(self):
         self.id = None
+        self.pki = None
         self.uint32_t_created = None
         self.uint32_t_modified = None
         self.float_latitude = None
@@ -60,10 +64,13 @@ class Position:
         self.uint32_satellite_visible = None
         self.uint32_satellite_locked = None
         self.fk_record_id = None
+        self.fki_record = None
 
     def from_json(self, data):
         if 'id' in data:
             self.id = data['id']
+        if 'pki' in data:
+            self.pki = data['pki']
         if 'uint32_t_created' in data:
             self.uint32_t_created = data['uint32_t_created']
         if 'uint32_t_modified' in data:
@@ -90,11 +97,14 @@ class Position:
             self.uint32_satellite_locked = data['uint32_satellite_locked']
         if 'fk_record_id' in data:
             self.fk_record_id = data['fk_record_id']
+        if 'fki_record' in data:
+            self.fki_record = data['fki_record']
 
 
 class Weather:
     def __init__(self):
         self.id = None
+        self.pki = None
         self.uint32_t_created = None
         self.uint32_t_modified = None
         self.vchar_station = None
@@ -108,6 +118,8 @@ class Weather:
     def from_json(self, data):
         if 'id' in data:
             self.id = data['id']
+        if 'pki' in data:
+            self.pki = data['pki']
         if 'uint32_t_created' in data:
             self.uint32_t_created = data['uint32_t_created']
         if 'uint32_t_modified' in data:
@@ -134,6 +146,7 @@ class Storage:
         self.image = None
         self.meta = None
         self.fk_record_id = None
+        self.fki_record_id = None
 
     def _b64_to_image(self, b64: np.array):
         bytes_array = base64.b64decode(b64.encode())
@@ -147,8 +160,8 @@ class Storage:
         return np.array(image)
 
     def from_json(self, data):
-        if 'pki_uuid' in data:
-            self.pki = data['pki_uuid']
+        if 'pki' in data:
+            self.pki = data['pki']
         if 'base64_bytes_array' in data:
             # converts to image on load
             self.image = self._b64_to_image(data['base64_bytes_array'])
@@ -156,6 +169,8 @@ class Storage:
             self.meta = data['meta']
         if 'fk_record_id' in data:
             self.fk_record_id = data['fk_record_id']
+        if 'fki_record_id' in data:
+            self.fki_record_id = data['fki_record_id']
 
 
 class FramesManager:
@@ -164,7 +179,19 @@ class FramesManager:
         self.jwt = None
 
     def set_jwt(self, jwt):
-        self.jwt = jwt
+        headers = {
+            'content-type': 'application/json',
+            'x-access-tokens': jwt
+        }
+
+        uri = "{}/protected".format(self.url)
+
+        response = requests.get(uri, headers=headers)
+
+        if response.status_code == 200:
+            self.jwt = jwt
+        else:
+            print('Invalid JWT. API responded with', response.status_code)
 
     def search(self, lat: float, lon: float, radius: float) -> list:
         uri = "{}/record/id/radius".format(self.url, id)
@@ -185,22 +212,22 @@ class FramesManager:
         else:
             return {'code': response.status_code}
 
-    def get_record(self, id: int) -> Record:
-        uri = "{}/record/{}".format(self.url, id)
+    def get_record(self, pki: str) -> Record:
+        uri = "{}/record/{}".format(self.url, pki)
 
         r = Record()
         r.from_json(self._get(uri))
         return r
 
-    def get_position(self, id: int) -> Position:
-        uri = "{}/position/{}".format(self.url, id)
+    def get_position(self, pki: str) -> Position:
+        uri = "{}/position/{}".format(self.url, pki)
 
         p = Position()
         p.from_json(self._get(uri))
         return p
 
-    def get_storage(self, id: int) -> Storage:
-        uri = "{}/storage/{}".format(self.url, id)
+    def get_storage(self, pki: str) -> Storage:
+        uri = "{}/storage/{}".format(self.url, pki)
 
         s = Storage()
         s.from_json(self._get(uri))
